<?php
namespace wcf\action;
use wcf\data\user\group\application\UserGroupApplication;
use wcf\data\user\group\application\UserGroupApplicationEditor;
use wcf\system\exception\IllegalLinkException;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\request\LinkHandler;
use wcf\system\user\notification\object\UserGroupApplicationUserNotificationObject;
use wcf\system\user\notification\UserNotificationHandler;
use wcf\system\WCF;
use wcf\util\HeaderUtil;

/**
 * Allows the user to revoke his application.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	action
 * @category	Community Framework (commercial)
 */
class UserGroupApplicationRevokeAction extends AbstractSecureAction {
	/**
	 * @see	wcf\action\AbstractAction::$loginRequired
	 */
	public $loginRequired = true;
	
	/**
	 * database object action
	 * @var	wcf\data\AbstractDatabaseObjectAction
	 */
	public $objectAction = null;
	
	/**
	 * given applicationID
	 * @var	integer
	 */
	public $applicationID = 0;
	
	/**
	 * instance of the application with the given id
	 * @var	wcf\data\user\group\application\UserGroupApplication
	 */
	public $application = null;
	
	/**
	 * @see	wcf\action\IAction::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_GET['id'])) $this->applicationID = intval($_GET['id']);
		$this->application = new UserGroupApplication($this->applicationID);
		if (!$this->application->applicationID) throw new IllegalLinkException();
	}
	
	/**
	 * @see	wcf\action\IAction::execute()
	 */
	public function execute() {
		parent::execute();
		
		if ($this->application->status == UserGroupApplication::STATUS_ACCEPTED || $this->application->status == UserGroupApplication::STATUS_CLOSED) {
			throw new PermissionDeniedException();
		}
		
		$applicationEditor = new UserGroupApplicationEditor($this->application);
		$applicationEditor->delete();
		$this->executed();
		
		// forward to user group list page
		HeaderUtil::redirect(LinkHandler::getInstance()->getLink('UserGroupList'));
		exit;
	}
}
