<?php
namespace wcf\action;
use wcf\data\user\group\UserGroup;
use wcf\data\user\UserProfileAction;
use wcf\system\exception\IllegalLinkException;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\request\LinkHandler;
use wcf\system\WCF;
use wcf\util\HeaderUtil;

/**
 * Allows the user to join open groups.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	action
 * @category	Community Framework (commercial)
 */
class UserGroupJoinAction extends AbstractSecureAction {
	/**
	 * @see	wcf\action\AbstractAction::$loginRequired
	 */
	public $loginRequired = true;
	
	/**
	 * database object action
	 * @var	wcf\data\AbstractDatabaseObjectAction
	 */
	public $objectAction = null;
	
	/**
	 * given groupID
	 * @var	integer
	 */
	public $groupID = 0;
	
	/**
	 * instance of the group with the given id
	 * @var	wcf\data\user\group\UserGroup
	 */
	public $group = null;
	
	/**
	 * @see	wcf\action\IAction::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_GET['id'])) $this->groupID = intval($_GET['id']);
		$this->group = new UserGroup($this->groupID);
		if (!$this->group->groupID) throw new IllegalLinkException();
	}
	
	/**
	 * @see	wcf\action\IAction::execute()
	 */
	public function execute() {
		parent::execute();
		
		// open
		if ($this->group->groupType != 5) {
			throw new PermissionDeniedException();
		}
		
		if ($this->group->isMember()) {
			throw new PermissionDeniedException();
		}
		
		if ($this->group->isAdminGroup()) {
			throw new PermissionDeniedException();
		}
		
		$groups = WCF::getUser()->getGroupIDs();
		$groups[] = $this->group->groupID;
		
		$data = array(
			'groups' => $groups
		);
		$this->objectAction = new UserProfileAction(array(WCF::getUser()->userID), 'update', $data);
		$this->objectAction->executeAction();
		
		$updateUserRankAction = new UserProfileAction(array(WCF::getUser()->userID), 'updateUserRank');
		$updateUserRankAction->executeAction();
		
		$updateUserOnlineMarkingAction = new UserProfileAction(array(WCF::getUser()->userID), 'updateUserOnlineMarking');
		$updateUserOnlineMarkingAction->executeAction();
		
		$this->executed();
		
		// forward to user group list page
		HeaderUtil::redirect(LinkHandler::getInstance()->getLink('UserGroupList'));
		exit;
	}
}
