<?php
namespace wcf\data\user\group;
use wcf\data\DatabaseObjectDecorator;
use wcf\system\WCF;

/**
 * Decorator for moderated user groups.
 *
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	data.user.group
 * @category	Community Framework (commercial)
 */
class ModeratedUserGroup extends DatabaseObjectDecorator {
	/**
	 * @see wcf\data\DatabaseObjectDecorator::$baseClass
	 */
	protected static $baseClass = 'wcf\data\user\group\UserGroup';
	
	/**
	 * true if the active user is a group leader
	 * @var boolean
	 */
	protected static $groupLeaderStatus = null;
	
	/**
	 * Returns true if the active use is a leader of this group.
	 * 
	 * @return	boolean
	 */
	public function isLeader() {
		$sql = "SELECT	COUNT(*) AS count
			FROM	wcf".WCF_N."_user_group_leader
			WHERE	groupID = ?
				AND leaderID = ?";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute(array($this->groupID, WCF::getUser()->userID));
		$row = $statement->fetchArray();
		if ($row['count']) return true;
		
		return false;
	}
	
	/**
	 * Returns true if the active user is a group leader.
	 * 
	 * @return	boolean
	 */
	public static function isGroupLeader() {
		if (self::$groupLeaderStatus === null) {
			$sql = "SELECT	COUNT(*) AS count
				FROM	wcf".WCF_N."_user_group_leader
				WHERE	leaderID = ?";
			$statement = WCF::getDB()->prepareStatement($sql);
			$statement->execute(array(WCF::getUser()->userID));
			$row = $statement->fetchArray();
			
			self::$groupLeaderStatus = ($row['count'] ? true : false);
		}
		
		return self::$groupLeaderStatus;
	}
}
