<?php
namespace wcf\data\user\group;
use wcf\data\user\UserProfileAction;
use wcf\data\user\User;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\exception\UserInputException;
use wcf\system\WCF;

/**
 * Executes moderated user group-related actions.
 *
 * @author	Marcel Werk
 * @copyright	2001-2013 WoltLab GmbH
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	data.user.group
 * @category	Community Framework (commercial)
 */
class ModeratedUserGroupAction extends UserGroupAction {
	/**
	 * user object
	 * @var	wcf\data\user\User
	 */
	protected $user = null;
	
	/**
	 * Adds a user to this group.
	 */
	public function addMember() {
		if (empty($this->objects)) {
			$this->readObjects();
		}
		
		$user = $this->parameters['user'];
		$groups = $user->getGroupIDs();
		
		foreach ($this->objects as $group) {
			$groups[] = $group->groupID;
		}
		
		$data = array(
			'groups' => $groups
		);
		$userAction = new UserProfileAction(array($user->userID), 'update', $data);
		$userAction->executeAction();
		
		$updateUserRankAction = new UserProfileAction(array($user->userID), 'updateUserRank');
		$updateUserRankAction->executeAction();
		
		$updateUserOnlineMarkingAction = new UserProfileAction(array($user->userID), 'updateUserOnlineMarking');
		$updateUserOnlineMarkingAction->executeAction();
	}
	
	/**
	 * Adds a user to this group.
	 */
	public function addMemberByName() {
		if (empty($this->objects)) {
			$this->readObjects();
		}
		
		if ($this->user === null) {
			$this->user = User::getUserByUsername($this->parameters['username']);
		}
		
		$action = new ModeratedUserGroupAction($this->objects, 'addMember', array('user' => $this->user));
		$action->executeAction();
	}
	
	/**
	 * Validates the 'addMemberByName' action.
	 */
	public function validateAddMemberByName() {
		$this->readString('username');
		
		$this->readObjects();
		
		if (empty($this->objects)) {
			throw new UserInputException('objectIDs');
		}
		
		foreach ($this->objects as $group) {
			$moderatedGroup = new ModeratedUserGroup($group->getDecoratedObject());
			if (!$moderatedGroup->isLeader()) {
				throw new PermissionDeniedException();
			}
		}
		
		// validate username
		$this->user = User::getUserByUsername($this->parameters['username']);
		if (!$this->user->userID) {
			throw new UserInputException('username', 'notFound');
		}
		
		foreach ($this->objects as $group) {
			if (in_array($group->groupID, $this->user->getGroupIDs())) {
				throw new UserInputException('username', 'alreadyMember');
			}
		}
	}
}
