<?php
namespace wcf\data\user\group\application;
use wcf\data\DatabaseObject;
use wcf\system\WCF;

/**
 * Represents an application to a moderated user group.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	data.user.group.application
 * @category	Community Framework (commercial)
 */
class UserGroupApplication extends DatabaseObject {
	/**
	 * default status
	 * @var	integer
	 */
	const STATUS_NEW = 0;
	
	/**
	 * the application is being processed by a group leader
	 * @var	integer
	 */
	const STATUS_IN_PROCESS = 1;
	
	/**
	 * the application was accepted
	 * @var	integer
	 */
	const STATUS_ACCEPTED = 2;
	
	/**
	 * the application was rejected, but the applicant may edit it
	 * @var	integer
	 */
	const STATUS_REJECTED = 3;
	
	/**
	 * the applicant may no longer edit the application
	 * @var	integer
	 */
	const STATUS_CLOSED = 5;
	
	/**
	 * @see	wcf\data\DatabaseObject::$databaseTableName
	 */
	protected static $databaseTableName = 'user_group_application';
	
	/**
	 * @see	wcf\data\DatabaseObject::$databaseTableIndexName
	 */
	protected static $databaseTableIndexName = 'applicationID';
	
	/**
	 * Returns the application matching applicant and groupID.
	 * 
	 * @param	integer		$applicant
	 * @param	integer		$groupID
	 * @return	wcf\data\user\group\application\UserGroupApplication
	 */
	public static function getApplicationByApplicantAndGroup($applicant, $groupID) {
		$sql = "SELECT	*
			FROM	wcf".WCF_N."_user_group_application
			WHERE		applicant = ?
				AND	groupID = ?";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute(array($applicant, $groupID));
		$row = $statement->fetchArray();
		if(!$row) $row = array();
		
		return new self(null, $row);
	}
}
