<?php
namespace wcf\form;
use wcf\data\modification\log\ViewableUserGroupApplicationModificationLogList;
use wcf\data\user\group\application\UserGroupApplication;
use wcf\data\user\group\application\UserGroupApplicationAction;
use wcf\data\user\group\UserGroup;
use wcf\system\exception\IllegalLinkException;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\request\LinkHandler;
use wcf\system\user\notification\object\UserGroupApplicationUserNotificationObject;
use wcf\system\user\notification\UserNotificationHandler;
use wcf\system\WCF;
use wcf\util\HeaderUtil;

/**
 * Allows the user to edit his application.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	form
 * @category	Community Framework (commercial)
 */
class UserGroupApplicationEditForm extends UserGroupApplyForm {
	/**
	 * @see	wcf\page\AbstractPage::$templateName
	 */
	public $templateName = 'userGroupApply';
	
	/**
	 * given applicationID
	 * @var	integer
	 */
	public $applicationID = 0;
	
	/**
	 * instance of the application with the given id
	 * @var	wcf\data\user\group\UserGroup
	 */
	public $application = null;
	
	/**
	 * application status
	 * @var	integer
	 */
	public $status = 0;
	
	/**
	 * reply
	 * @var	string
	 */
	public $reply = '';
	
	/**
	 * modification log
	 * @var	wcf\data\modification\log\ViewableUserGroupApplicationModificationLogList
	 */
	public $modificationLog = null;
	
	/**
	 * @see wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		AbstractForm::readParameters();
		
		if (isset($_GET['id'])) $this->applicationID = intval($_GET['id']);
		$this->application = new UserGroupApplication($this->applicationID);
		if (!$this->application->applicationID) throw new IllegalLinkException();
		
		$this->group = new UserGroup($this->application->groupID);
		
		if ($this->application->applicant != WCF::getUser()->userID) {
			throw new PermissionDeniedException();
		}
		
		if ($this->application->status == UserGroupApplication::STATUS_ACCEPTED || $this->application->status == UserGroupApplication::STATUS_CLOSED) {
			throw new PermissionDeniedException();
		}
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (empty($_POST)) {
			$this->reason = $this->application->reason;
		}
		$this->status = $this->application->status;
		$this->reply = $this->application->reply;
		
		$this->modificationLog = new ViewableUserGroupApplicationModificationLogList();
		$this->modificationLog->setApplicationData(array($this->application->applicationID));
		$this->modificationLog->readObjects();
	}
	
	/**
	 * @see	wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'application' => $this->application,
			'status' => $this->status,
			'reply' => $this->reply,
			'modificationLog' => $this->modificationLog
		));
	}
	
	/**
	 * @see	wcf\form\IForm::save()
	 */
	public function save() {
		AbstractForm::save();
		
		$this->objectAction = new UserGroupApplicationAction(array($this->application->applicationID), 'update', array(
			'data' => array(
				'time' => TIME_NOW,
				'reason' => $this->reason,
			)
		));
		$this->objectAction->executeAction();
		$this->saved();
		
		// forward to user group list page
		HeaderUtil::redirect(LinkHandler::getInstance()->getLink('UserGroupList'));
		exit;
	}
}
