<?php
namespace wcf\form;
use wcf\data\user\group\application\UserGroupApplication;
use wcf\data\user\group\application\UserGroupApplicationAction;
use wcf\data\user\group\ModeratedUserGroupAction;
use wcf\data\user\group\ModeratedUserGroup;
use wcf\data\user\User;
use wcf\data\user\UserProfileAction;
use wcf\system\breadcrumb\Breadcrumb;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\exception\UserInputException;
use wcf\system\menu\user\UserMenu;
use wcf\system\request\LinkHandler;
use wcf\system\user\notification\object\UserGroupApplicationUserNotificationObject;
use wcf\system\user\notification\UserNotificationHandler;
use wcf\system\WCF;
use wcf\util\HeaderUtil;
use wcf\util\StringUtil;

/**
 * Allows the group leader to edit the status of an application.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	form
 * @category	Community Framework (commercial)
 */
class UserGroupManageApplicationEditForm extends UserGroupApplicationEditForm {
	/**
	 * @see	wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		try {
			parent::readParameters();
		}
		catch (PermissionDeniedException $e) {
			$moderatedUserGroup = new ModeratedUserGroup($this->group);
			if (!$moderatedUserGroup->isLeader()) throw new PermissionDeniedException();
		}
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (empty($_POST)) {
			$this->status = $this->application->status == UserGroupApplication::STATUS_NEW ? UserGroupApplication::STATUS_IN_PROCESS : $this->application->status;
			$this->reply = $this->application->reply;
		}
	}
	
	/**
	 * @see	wcf\page\IPage::show()
	 */
	public function show() {
		// set active tab
		UserMenu::getInstance()->setActiveMenuItem('wcf.user.menu.moderatedUserGroups');
		
		// add breadcrumbs
		WCF::getBreadcrumbs()->add(new Breadcrumb(WCF::getLanguage()->get('wcf.user.menu.moderatedUserGroups'), LinkHandler::getInstance()->getLink('ModeratedUserGroupList')));
		WCF::getBreadcrumbs()->add(new Breadcrumb(WCF::getLanguage()->get($this->group->groupName), LinkHandler::getInstance()->getLink('UserGroupManageApplicationList', array('id' => $this->group->groupID))));
		
		AbstractForm::show();
	}
	
	/**
	 * @see	wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'isGroupLeader' => true
		));
	}
	
	/**
	 * @see	wcf\form\IForm::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['status'])) $this->status = intval($_POST['status']);
		if (isset($_POST['reply'])) $this->reply = StringUtil::trim($_POST['reply']);
	}
	
	/**
	 * @see	wcf\form\IForm::validate()
	 */
	public function validate() {
		AbstractForm::validate();
		
		switch ($this->status) {
			case UserGroupApplication::STATUS_IN_PROCESS:
			case UserGroupApplication::STATUS_ACCEPTED:
			case UserGroupApplication::STATUS_REJECTED:
			case UserGroupApplication::STATUS_CLOSED:
				// they are all fine
			break;
			default:
				throw new UserInputException('status');
			break;
		}
	}
	
	/**
	 * @see	wcf\form\IForm::save()
	 */
	public function save() {
		AbstractForm::save();
		
		if ($this->application->status != UserGroupApplication::STATUS_ACCEPTED) {
			$this->objectAction = new UserGroupApplicationAction(array($this->application->applicationID), 'update', array(
				'data' => array(
					'time' => TIME_NOW,
					'status' => $this->status,
					'reply' => $this->reply
				)
			));
			$this->objectAction->executeAction();
			
			if ($this->status != $this->application->status) {
				switch ($this->status) {
					case UserGroupApplication::STATUS_ACCEPTED:
						$applicant = new User($this->application->applicant);
						$groupAction = new ModeratedUserGroupAction(array($this->group), 'addMember', array('user' => $applicant));
						$groupAction->executeAction();
						
						UserNotificationHandler::getInstance()->fireEvent('edited', 'com.woltlab.wcf.moderatedUserGroup.application', new UserGroupApplicationUserNotificationObject($this->application), array($this->application->applicant), array('groupID' => $this->group->groupID, 'newStatus' => 'accepted'));
					break;
					case UserGroupApplication::STATUS_REJECTED:
						UserNotificationHandler::getInstance()->fireEvent('edited', 'com.woltlab.wcf.moderatedUserGroup.application', new UserGroupApplicationUserNotificationObject($this->application), array($this->application->applicant), array('groupID' => $this->group->groupID, 'newStatus' => 'rejected'));
					break;
					case UserGroupApplication::STATUS_CLOSED:
						UserNotificationHandler::getInstance()->fireEvent('edited', 'com.woltlab.wcf.moderatedUserGroup.application', new UserGroupApplicationUserNotificationObject($this->application), array($this->application->applicant), array('groupID' => $this->group->groupID, 'newStatus' => 'closed'));
					break;
				}
			}
			
			$this->saved();
		}
		else {
			throw new PermissionDeniedException();
		}
		
		// forward to user application list page
		HeaderUtil::redirect(LinkHandler::getInstance()->getLink('UserGroupManageApplicationList', array('id' => $this->group->groupID)));
		exit;
	}
}
