<?php
namespace wcf\page;
use wcf\acp\page\UserGroupListPage;
use wcf\data\user\group\application\UserGroupApplication;
use wcf\data\user\UserList;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\menu\user\UserMenu;
use wcf\system\WCF;

/**
 * Lists groups the current user leads.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	page
 * @category	Community Framework (commercial)
 */
class ModeratedUserGroupListPage extends UserGroupListPage {
	/**
	 * @see	wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = '';
	
	/**
	 * @see	wcf\page\AbstractPage::$loginRequired
	 */
	public $loginRequired = true;
	
	/**
	 * @see	wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array();
	
	/**
	 * list of applications for the current user
	 * @var	wcf\data\user\group\application\UserGroupApplicationList
	 */
	public $applicationList = null;
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$itemsPerPage
	 */
	public $itemsPerPage = 7;
	
	/**
	 * @see	wcf\page\MultipleLinkPage::initObjectList()
	 */
	protected function initObjectList() {
		SortablePage::initObjectList();
		
		$this->objectList->sqlSelects .= "(SELECT COUNT(*) FROM wcf".WCF_N."_user_group_application WHERE groupID = user_group.groupID) AS applications,
		(SELECT COUNT(*) FROM wcf".WCF_N."_user_group_application WHERE groupID = user_group.groupID AND status = ".UserGroupApplication::STATUS_NEW.") AS newApplications,
		(SELECT COUNT(*) FROM wcf".WCF_N."_user_to_group WHERE groupID = user_group.groupID) AS members";
		$this->objectList->sqlJoins = $this->objectList->sqlConditionJoins .= " INNER JOIN wcf".WCF_N."_user_group_leader group_leader ON user_group.groupID = group_leader.groupID";
		$this->objectList->getConditionBuilder()->add('group_leader.leaderID = ?', array(WCF::getUser()->userID));
		
		// read group leaders
		$this->leaderList = new UserList();
		$this->leaderList->sqlJoins .= " INNER JOIN wcf".WCF_N."_user_group_leader group_leader ON user_table.userID = group_leader.leaderID";
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (!count($this->objectList)) throw new PermissionDeniedException();
		
		// assign leaders to groups
		$this->leaderList->readObjects();
		$sql = "SELECT	*
			FROM	wcf".WCF_N."_user_group_leader";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute();
		while ($row = $statement->fetchArray()) {
			if (($group = $this->objectList->search($row['groupID'])) === null) continue;
			
			if (!is_array($group->leader)) $group->leader = array();
			$group->leader[] = $this->leaderList->search($row['leaderID']);
		}
	}
	
	/**
	 * @see	wcf\page\IPage::show()
	 */
	public function show() {
		// set active tab
		UserMenu::getInstance()->setActiveMenuItem('wcf.user.menu.moderatedUserGroups');
		
		parent::show();
	}
}
