<?php
namespace wcf\page;
use wcf\data\user\group\application\UserGroupApplicationList;
use wcf\data\user\group\UserGroup;
use wcf\data\user\group\UserGroupList;
use wcf\data\user\UserList;
use wcf\system\exception\IllegalLinkException;
use wcf\system\menu\user\UserMenu;
use wcf\system\WCF;

/**
 * Lists open, moderated and closed moderated groups.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	page
 * @category	Community Framework (commercial)
 */
class UserGroupListPage extends \wcf\acp\page\UserGroupListPage {
	/**
	 * @see	wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = '';
	
	/**
	 * @see	wcf\page\AbstractPage::$loginRequired
	 */
	public $loginRequired = true;
	
	/**
	 * @see	wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array();
	
	/**
	 * list of applications for the current user
	 * @var	wcf\data\user\group\application\UserGroupApplicationList
	 */
	public $applicationList = null;
	
	/**
	 * @see	wcf\page\MultipleLinkPage::$itemsPerPage
	 */
	public $itemsPerPage = 7;
	
	/**
	 * @see	wcf\page\MultipleLinkPage::initObjectList()
	 */
	protected function initObjectList() {
		SortablePage::initObjectList();
		
		$userGroupList = new UserGroupList();
		$userGroupList->getConditionBuilder()->add('user_group.groupType NOT IN (?)', array(array(
			UserGroup::EVERYONE,
			UserGroup::GUESTS,
			UserGroup::USERS,
			UserGroup::OTHER
		)));
		$userGroupList->readObjects();
		$validGroups = array(0);
		// check whether there are any admin groups
		foreach ($userGroupList as $userGroup) {
			if (!$userGroup->isAdminGroup()) $validGroups[] = $userGroup->groupID;
		}
		
		// sort out groups that cannot be joined
		$this->objectList->getConditionBuilder()->add('user_group.groupID IN (?)', array($validGroups));
		
		// read applications
		$this->applicationList = new UserGroupApplicationList();
		$this->applicationList->getConditionBuilder()->add('applicant = ?', array(WCF::getUser()->userID));
		
		// read group leaders
		$this->leaderList = new UserList();
		$this->leaderList->sqlJoins .= " INNER JOIN wcf".WCF_N."_user_group_leader group_leader ON user_table.userID = group_leader.leaderID";
	}
	
	/**
	 * @see	wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (!count($this->objectList)) throw new IllegalLinkException();
		
		// assign applications to groups
		$this->applicationList->readObjects();
		foreach ($this->applicationList as $application) {
			if (($group = $this->objectList->search($application->groupID)) === null) continue;
			
			$group->application = $application;
		}
		
		// assign leaders to groups
		$this->leaderList->readObjects();
		$sql = "SELECT	*
			FROM	wcf".WCF_N."_user_group_leader";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute();
		while ($row = $statement->fetchArray()) {
			if (($group = $this->objectList->search($row['groupID'])) === null) continue;
			
			if (!is_array($group->leader)) $group->leader = array();
			$group->leader[] = $this->leaderList->search($row['leaderID']);
		}
	}
	
	/**
	 * @see	wcf\page\IPage::show()
	 */
	public function show() {
		// set active tab
		UserMenu::getInstance()->setActiveMenuItem('wcf.user.menu.accessibleUserGroups');
		
		parent::show();
	}
}
