<?php
namespace wcf\system\log\modification;
use wcf\data\user\group\application\UserGroupApplication;
use wcf\system\exception\SystemException;

/**
 * Handles user group application modification logs.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	system.log.modification
 * @category	Community Framework (commercial)
 */
class UserGroupApplicationModificationLogHandler extends ModificationLogHandler {
	/**
	 * Adds a log entry for a change of the status.
	 * 
	 * @param	wcf\data\user\group\application\UserGroupApplication	$application
	 * @param	integer							$newStatus
	 */
	public function changeStatus(UserGroupApplication $application, $newStatus) {
		switch ($newStatus) {
			case UserGroupApplication::STATUS_NEW:
			case UserGroupApplication::STATUS_IN_PROCESS:
			case UserGroupApplication::STATUS_ACCEPTED:
			case UserGroupApplication::STATUS_REJECTED:
			case UserGroupApplication::STATUS_CLOSED:
				// they are fine
			break;
			default:
				throw new SystemException('Unexpected value for $newStatus, expected one of UserGroupApplication::STATUS_*, but got: '.$newStatus);
		}
		
		$this->add($application, 'changeStatus', array('newStatus' => $newStatus));
	}
	
	/**
	 * Adds a log entry for an edit of the reason.
	 * 
	 * @param	wcf\data\user\group\application\UserGroupApplication	$application
	 */
	public function editReason(UserGroupApplication $application) {
		$this->add($application, 'editReason');
	}
	
	/**
	 * Adds a log entry for an edit of the reply.
	 * 
	 * @param	wcf\data\user\group\application\UserGroupApplication	$application
	 */
	public function editReply(UserGroupApplication $application) {
		$this->add($application, 'editReply');
	}
	
	/**
	 * Deletes log entries for the given applications.
	 * 
	 * @param	array<integer>	$applicationIDs
	 */
	public function delete(array $applicationIDs) {
		$this->_remove('com.woltlab.wcf.moderatedUserGroup.application', $applicationIDs);
	}
	
	/**
	 * Adds a user group application modification log entry.
	 * 
	 * @param	wcf\data\user\group\application\UserGroupApplication	$application
	 * @param	string							$action
	 * @param	array							$additionalData
	 */
	public function add(UserGroupApplication $application, $action, array $additionalData = array()) {
		$this->_add('com.woltlab.wcf.moderatedUserGroup.application', $application->applicationID, $action, $additionalData);
	}
}
