<?php
namespace wcf\system\user\notification\event;
use wcf\data\user\group\ModeratedUserGroup;
use wcf\data\user\group\UserGroup;
use wcf\system\request\LinkHandler;
use wcf\system\user\notification\event\AbstractUserNotificationEvent;

/**
 * Notification for the group leaders when a new application is created.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	system.user.notification.event
 * @category	Community Framework (commercial)
 */
class UserGroupApplicationCreatedUserNotificationEvent extends AbstractUserNotificationEvent {
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getLink()
	 */
	public function getLink() {
		return LinkHandler::getInstance()->getLink('UserGroupManageApplicationEdit', array(
			'id' => $this->userNotificationObject->applicationID
		));
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getMessage()
	 */
	public function getTitle() {
		return $this->getLanguage()->get('wcf.user.notification.com.woltlab.wcf.moderatedUserGroup.application.created.title');
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getMessage()
	 */
	public function getMessage() {
		return $this->getLanguage()->getDynamicVariable('wcf.user.notification.com.woltlab.wcf.moderatedUserGroup.application.created.message', array(
			'application' => $this->userNotificationObject,
			'author' => $this->author,
			'group' => UserGroup::getGroupByID($this->additionalData['groupID'])
		));
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getEmailMessage()
	 */
	public function getEmailMessage($notificationType = 'instant') {
		return $this->getLanguage()->getDynamicVariable('wcf.user.notification.com.woltlab.wcf.moderatedUserGroup.application.created.mail', array(
			'application' => $this->userNotificationObject,
			'author' => $this->author,
			'group' => UserGroup::getGroupByID($this->additionalData['groupID'])
		));
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::isVisible()
	 */
	public function isVisible() {
		return ModeratedUserGroup::isGroupLeader();
	}
}
