<?php
namespace wcf\system\user\notification\event;
use wcf\data\user\group\application\UserGroupApplication;
use wcf\data\user\group\UserGroup;
use wcf\system\user\notification\event\AbstractUserNotificationEvent;
use wcf\system\request\LinkHandler;

/**
 * Notification for the applicant when their application is edited.
 * 
 * @author	Tim Duesterhus
 * @copyright	2001-2013 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.moderatedUserGroup
 * @subpackage	system.user.notification.event
 * @category	Community Framework (commercial)
 */
class UserGroupApplicationEditedUserNotificationEvent extends AbstractUserNotificationEvent {
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getLink()
	 */
	public function getLink() {
		if ($this->userNotificationObject->status == UserGroupApplication::STATUS_ACCEPTED || $this->userNotificationObject->status == UserGroupApplication::STATUS_CLOSED) {
			return LinkHandler::getInstance()->getLink('UserGroupList');
		}
		else {
			return LinkHandler::getInstance()->getLink('UserGroupApplicationEdit', array(
				'id' => $this->userNotificationObject->applicationID
			));
		}
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getMessage()
	 */
	public function getTitle() {
		return $this->getLanguage()->getDynamicVariable('wcf.user.notification.com.woltlab.wcf.moderatedUserGroup.application.edited.title', array(
			'newStatus' => $this->additionalData['newStatus']
		));
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getMessage()
	 */
	public function getMessage() {
		return $this->getLanguage()->getDynamicVariable('wcf.user.notification.com.woltlab.wcf.moderatedUserGroup.application.edited.message', array(
			'application' => $this->userNotificationObject,
			'author' => $this->author,
			'group' => UserGroup::getGroupByID($this->additionalData['groupID']),
			'newStatus' => $this->additionalData['newStatus']
		));
	}
	
	/**
	 * @see	wcf\system\user\notification\event\IUserNotificationEvent::getEmailMessage()
	 */
	public function getEmailMessage($notificationType = 'instant') {
		return $this->getLanguage()->getDynamicVariable('wcf.user.notification.com.woltlab.wcf.moderatedUserGroup.application.edited.mail', array(
			'application' => $this->userNotificationObject,
			'author' => $this->author,
			'group' => UserGroup::getGroupByID($this->additionalData['groupID']),
			'newStatus' => $this->additionalData['newStatus']
		));
	}
}
